config = {
    'balrog_servers': [
        {
            'balrog_api_root': 'https://aus4-admin-dev.allizom.org/api',
            'ignore_failures': False,
            'balrog_usernames': {
                'icecat': 'stage-ffxbld',
                'thunderbird': 'stage-tbirdbld',
                'mobile': 'stage-ffxbld',
                'IceCatMobile': 'stage-ffxbld',
            }
        }
    ]
}
